pub struct DecoderBuilder { /* private fields */ }Expand description
Implementations
Sourceimpl DecoderBuilder
impl DecoderBuilder
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new DecoderBuilder instance with no source specified.
Sourcepub fn use_file(self, path: impl Into<PathBuf>) -> Self
pub fn use_file(self, path: impl Into<PathBuf>) -> Self
Specifies the source as a file path.
Example
let builder = DecoderBuilder::new()
.use_file("path/to/project.sb3");Sourcepub fn use_bytes(self, bytes: &[u8]) -> Self
pub fn use_bytes(self, bytes: &[u8]) -> Self
Specifies the source as in-memory bytes.
Example
let builder = DecoderBuilder::new()
.use_bytes(include_bytes!("path/to/project.sb3"));Sourcepub fn build(self) -> Result<Decoder, BuilderError>
pub fn build(self) -> Result<Decoder, BuilderError>
Builds the Decoder from the specified source.
Example
let decoder = match builder.build() {
Ok(decoder) => decoder,
Err(e) => panic!("Failed to build decoder: {}", e),
};Errors
Returns BuilderError::FileRead if there is an error reading the file.
Returns BuilderError::NoSource if no source was specified.
Returns BuilderError::Decode if there is an error creating the decoder.