Module raw_block

Module raw_block 

The raw_block module contains the RawBlock struct and related functionality.

Structs

RawBlock
The RawBlock struct represents a block in its raw form in a Scratch 3.0 project. It contains the opcode, inputs, fields, next block, parent block, and shadow status.
RawBlockInput
The RawBlockInput struct represents an input to a block in its raw form in a Scratch 3.0 project.