The raw_target module contains the RawTarget enum.
It also contains the RawSprite, RawVariable and RawStage structs.
Structs
- RawSprite
- The
RawSpritestruct represents a sprite in its raw form in a Scratch 3.0 project. - RawStage
- The
RawStagestruct represents the stage in its raw form in a Scratch 3.0 project. - RawVariable
- The
RawVariablestruct represents a variable in its raw form in a Scratch 3.0 project.