pub struct RawSprite {Show 16 fields
pub name: String,
pub variables: HashMap<String, RawVariable>,
pub lists: HashMap<String, (String, Vec<Value>)>,
pub blocks: HashMap<String, RawBlock>,
pub current_costume: usize,
pub costumes: Vec<RawCostume>,
pub sounds: Vec<RawSound>,
pub volume: u8,
pub layer_order: isize,
pub visible: bool,
pub x: i32,
pub y: i32,
pub size: u32,
pub direction: i32,
pub draggable: bool,
pub rotation_style: String,
}Expand description
The RawSprite struct represents a sprite in its raw form in a Scratch 3.0 project.
Fields
name: StringThe name of the sprite.
variables: HashMap<String, RawVariable>The variables of the sprite.
lists: HashMap<String, (String, Vec<Value>)>The lists of the sprite.
blocks: HashMap<String, RawBlock>The blocks of the sprite stored as a map from block ID to RawBlock.
current_costume: usizeThe index of the current costume.
costumes: Vec<RawCostume>The costumes of the sprite.
sounds: Vec<RawSound>The sounds of the sprite.
volume: u8The volume of the sprite.
layer_order: isizeThe layer of the sprite.
visible: boolIf the sprite is visible.
x: i32The x position of the sprite.
y: i32The y position of the sprite.
size: u32The size of the sprite.
direction: i32The direction of the sprite.
draggable: boolIf the sprite is draggable.
rotation_style: StringThe rotation style of the sprite.