pub enum BuilderError {
NoSource,
FileRead(Error),
Decode(DecodeError),
}Expand description
Represents errors that can occur during the building of a decoder.
This enum encapsulates errors related to invalid configurations or missing parameters.
Variants
NoSource
Error indicating that no source was specified for the decoder.
FileRead(Error)
Error indicating that reading the specified file failed.
Decode(DecodeError)
Error that contains a DecodeError.