Module structs

Module structs 

The project and everything inside it, all rust-ified into structs.

Re-exports

pub use costume::*;
pub use project::*;
pub use sound::*;
pub use target::*;
pub use variable::*;
pub use block::*;

Modules

block
This module provides all the necessary components to decode and work with Scratch 3.0 blocks.
costume
The costume module contains the Costume struct and related functionality.
project
A project that contains all the decoded data from a Scratch 3.0 project file (.sb3).
sound
The sound module contains the Sound struct and related functionality.
target
The target module containing the Target enum.
variable
Module for handling Scratch 3.0 values and variables.