Module block

Module block 

This module provides all the necessary components to decode and work with Scratch 3.0 blocks.

The main struct in this module is Block, which represents a Scratch block with its opcode, inputs, fields, and other properties.

Re-exports

pub use block::*;
pub use opcodes::*;
pub use input::*;

Modules

block
This module provides the Block struct. It represents a Scratch block inside a target.
input
This module defines the structures and enums for handling input values in blocks.
opcodes
This module defines the various opcodes used in Scratch 3.0 blocks.