Module block

Module block 

This module provides the Block struct. It represents a Scratch block inside a target.

Structs

Block
The Block struct represents a Scratch block inside a target. It has an opcode, some inputs, some fields, and thats about it.

Functions

decode_scripts
Decodes scripts from a map with String and RawBlocks as key and value, respectively.

Type Aliases

Script