Module input

Module input 

This module defines the structures and enums for handling input values in blocks.

Structs

BlockInput
The BlockInput struct wraps an InputValue.

Enums

InputValue
Represents the different types of input values that can be associated with a block.