pub struct BlockInput {
pub shadow: bool,
pub value: InputValue,
}Expand description
The BlockInput struct wraps an InputValue.
Blocks contain a map of input names to BlockInputs.
Fields
shadow: boolIf the block is a shadow block.
value: InputValueThe input value, which can be a literal, broadcast, or nested block.
Implementations
Sourceimpl BlockInput
impl BlockInput
Sourcepub fn new(
raw: RawBlockInput,
blocks: &HashMap<String, RawBlock>,
) -> Result<Self, DecodeError>
pub fn new( raw: RawBlockInput, blocks: &HashMap<String, RawBlock>, ) -> Result<Self, DecodeError>
Creates a new BlockInput from a RawBlockInput and the entire map of blocks to
un-flatten the structure.