Module opcodes

Module opcodes 

This module defines the various opcodes used in Scratch 3.0 blocks.

All opcodes are divided into 9 core categories. Note: There are 11 more categories that aren’t supported yet in this crate.

Enums

ControlOpcode
Control opcodes
DataOpcode
Data opcodes
EventsOpcode
Events opcodes
LooksOpcode
Looks opcodes
MotionOpcode
Motion opcodes
Opcode
This is the Opcode enum, which encompasses all the different opcodes used in Scratch 3.0 blocks.
OperatorsOpcode
Operators opcodes
ProceduresOpcode
My Blocks (Procedures) opcodes
SensingOpcode
Sensing opcodes
SoundOpcode
Sound opcodes