pub enum Opcode {
Motion(MotionOpcode),
Looks(LooksOpcode),
Sound(SoundOpcode),
Events(EventsOpcode),
Control(ControlOpcode),
Sensing(SensingOpcode),
Operators(OperatorsOpcode),
Data(DataOpcode),
Procedures(ProceduresOpcode),
}Expand description
This is the Opcode enum, which encompasses all the different opcodes used in Scratch 3.0
blocks.
You can parse an opcode from a string slice using the str::parse method.
Variants
Motion(MotionOpcode)
Motion opcodes
Looks(LooksOpcode)
Looks opcodes
Sound(SoundOpcode)
Sound opcodes
Events(EventsOpcode)
Events opcodes
Control(ControlOpcode)
Control opcodes
Sensing(SensingOpcode)
Sensing opcodes
Operators(OperatorsOpcode)
Operators opcodes
Data(DataOpcode)
Data opcodes
Procedures(ProceduresOpcode)
My Blocks (Procedures) opcodes