Project

Struct Project 

pub struct Project {
    pub sprites: Vec<Sprite>,
    pub stage: Stage,
}
The Project struct represents a Scratch 3.0 project.

It contains all the decoded data from a .sb3 file, including sprites and the stage.

Fields

sprites: Vec<Sprite>

Contains all the sprites in the project.

stage: Stage

Contains the stage of the project.

Implementations

Source

impl Project

pub fn new( raw: RawProject, zip: &mut ZipArchive<Cursor<Vec<u8>>>, ) -> Result<Self, DecodeError>

Returns a new project from a RawProject and the zip archive.

Errors

Returns DecodeError::Zip if there is an error reading the ZIP archive. Returns DecodeError::NotFound if something expected is not found in the archive or in the JSON data.

pub fn global_variables(&self) -> &HashMap<String, Variable>

Returns a reference to the global variables from the stage.

Example
let project = decoder.decode().unwrap();
let global_vars = project.global_variables();
pub fn global_variables_mut(&mut self) -> &mut HashMap<String, Variable>

Returns a mutable reference to the global variables from the stage.

Example
let mut project = decoder.decode().unwrap();
let mut global_vars = project.global_variables_mut();
pub fn broadcasts(&self) -> Vec<Broadcast>

Returns all the broadcast messages in the project.

pub fn get(&self, name: &str) -> Option<&Sprite>

Returns a reference to a sprite by its name, if it exists.

Example
let project = decoder.decode().unwrap();
let sprite = project.get("Cat");
if let Some(sprite) = sprite {
  // Do something with the sprite
}
pub fn get_mut(&mut self, name: &str) -> Option<&mut Sprite>

Returns a mutable reference to a sprite by its name, if it exists.

Example
let mut project = decoder.decode().unwrap();
let sprite = project.get_mut("Cat");
if let Some(sprite) = sprite {
  // Do something with the sprite
}