pub struct Sound {
pub data: Vec<i16>,
pub rate: u32,
}Expand description
The Sound struct represents a sound in a Scratch 3.0 project.
Fun fact: The spec data in the JSON file is often incorrect but the wave file itself is fine. Don’t trust the spec data from the JSON!
Fields
data: Vec<i16>The PCM sample data of the sound.
rate: u32The sample rate of the sound.