Module target

Module target 

The target module containing the Target enum.

It also contains the Sprite, Broadcast and Stage structs.

Structs

Broadcast
The Broadcast struct represents a usable broadcast message in a Scratch 3.0 project.
Sprite
The Sprite struct represents a sprite in a Scratch 3.0 project.
Stage
The Stage struct represents the stage in a Scratch 3.0 project.

Enums

RotationStyle
The RotationStyle enum represents the rotation style of a sprite in a Scratch 3.0 project.
Target
The Target enum represents either a sprite or the stage in a Scratch 3.0 project.