pub struct Stage {
pub variables: HashMap<String, Variable>,
pub lists: HashMap<String, List>,
pub broadcasts: Vec<Broadcast>,
pub scripts: Vec<Script>,
pub current_backdrop: usize,
pub sounds: HashMap<String, Sound>,
pub volume: f32,
/* private fields */
}Expand description
The Stage struct represents the stage in a Scratch 3.0 project.
Fields
variables: HashMap<String, Variable>Contains all the global variables in the project.
lists: HashMap<String, List>broadcasts: Vec<Broadcast>Contains all the broadcasts in the project.
scripts: Vec<Script>Contains all the scripts in the stage.
current_backdrop: usizeThe index of the current backdrop.
sounds: HashMap<String, Sound>Contains all the sounds of the stage.
volume: f32The stage’s volume (0.0 = 0%, 1.0 = 100%)
Implementations
Sourceimpl Stage
impl Stage
Sourcepub fn new(
raw: RawStage,
zip: &mut ZipArchive<Cursor<Vec<u8>>>,
) -> Result<Self, DecodeError>
pub fn new( raw: RawStage, zip: &mut ZipArchive<Cursor<Vec<u8>>>, ) -> Result<Self, DecodeError>
Returns a new stage from a RawStage and the zip archive.
Sourcepub fn get_backdrop(&self, name: &str) -> Option<&Costume>
pub fn get_backdrop(&self, name: &str) -> Option<&Costume>
Returns a reference to a backdrop by its name, if it exists.
Sourcepub fn get_backdrop_mut(&mut self, name: &str) -> Option<&mut Costume>
pub fn get_backdrop_mut(&mut self, name: &str) -> Option<&mut Costume>
Returns a mutable reference to a backdrop by its name, if it exists.
Sourcepub fn backdrop_names(&self) -> Vec<&String>
pub fn backdrop_names(&self) -> Vec<&String>
Returns all the backdrop names in the stage.