pub struct RawBlockInput {
pub shadow: u8,
pub kind: u8,
pub value: Value,
}Expand description
The RawBlockInput struct represents an input to a block in its raw form in a Scratch 3.0
project.
Fields
shadow: u8The shadow type of the block.
1 for shadow block,
2 for non-shadow block.
3 for shadow block but is obscured by a non-shadow block.
kind: u8The type of the input.
4 to 8 for a number.
9 for hex color string.
10 for string.
11 for broadcast.
12 and 13 for variables and lists, respectively.
A variant is used by this crate to represent a block reference (i.e., when the input is
another block). In this case, the kind will be 0, and the value will be a string
of the block ID.
value: ValueThe value of the input.
number for 4 to 8,
string for 9 to 13.