Module error

Module error 

Error types for the application.

This module defines custom error types to handle various error scenarios that may occur during the decoding process.

Enums

BuilderError
Represents errors that can occur during the building of a decoder.
DecodeError
Represents errors that can occur during the decoding process.