This module defines the structures and enums for handling input values in blocks.
Structs
- Block
Input - The
BlockInputstruct wraps anInputValue.
Enums
- Input
Value - Represents the different types of input values that can be associated with a block.