This module defines the various opcodes used in Scratch 3.0 blocks.
All opcodes are divided into 9 core categories. Note: There are 11 more categories that aren’t supported yet in this crate.
Enums
- Control
Opcode - Control opcodes
- Data
Opcode - Data opcodes
- Events
Opcode - Events opcodes
- Looks
Opcode - Looks opcodes
- Motion
Opcode - Motion opcodes
- Opcode
- This is the
Opcodeenum, which encompasses all the different opcodes used in Scratch 3.0 blocks. - Operators
Opcode - Operators opcodes
- Procedures
Opcode - My Blocks (Procedures) opcodes
- Sensing
Opcode - Sensing opcodes
- Sound
Opcode - Sound opcodes