pub struct Project {
pub sprites: Vec<Sprite>,
pub stage: Stage,
}Expand description
The Project struct represents a Scratch 3.0 project.
It contains all the decoded data from a .sb3 file, including sprites and the stage.
Fields
sprites: Vec<Sprite>Contains all the sprites in the project.
stage: StageContains the stage of the project.
Implementations
Sourceimpl Project
impl Project
Sourcepub fn new(
raw: RawProject,
zip: &mut ZipArchive<Cursor<Vec<u8>>>,
) -> Result<Self, DecodeError>
pub fn new( raw: RawProject, zip: &mut ZipArchive<Cursor<Vec<u8>>>, ) -> Result<Self, DecodeError>
Returns a new project from a RawProject and the zip archive.
Errors
Returns DecodeError::Zip if there is an error reading the ZIP archive.
Returns DecodeError::NotFound if something expected is not found in the archive or in
the JSON data.
Sourcepub fn global_variables(&self) -> &HashMap<String, Variable>
pub fn global_variables(&self) -> &HashMap<String, Variable>
Returns a reference to the global variables from the stage.
Example
let project = decoder.decode().unwrap();
let global_vars = project.global_variables();Sourcepub fn global_variables_mut(&mut self) -> &mut HashMap<String, Variable>
pub fn global_variables_mut(&mut self) -> &mut HashMap<String, Variable>
Returns a mutable reference to the global variables from the stage.
Example
let mut project = decoder.decode().unwrap();
let mut global_vars = project.global_variables_mut();Sourcepub fn broadcasts(&self) -> Vec<Broadcast>
pub fn broadcasts(&self) -> Vec<Broadcast>
Returns all the broadcast messages in the project.