Structs
- Broadcast
- The
Broadcaststruct represents a usable broadcast message in a Scratch 3.0 project. - Sprite
- The
Spritestruct represents a sprite in a Scratch 3.0 project. - Stage
- The
Stagestruct represents the stage in a Scratch 3.0 project.
Enums
- Rotation
Style - The
RotationStyleenum represents the rotation style of a sprite in a Scratch 3.0 project. - Target
- The
Targetenum represents either a sprite or the stage in a Scratch 3.0 project.