Module for handling Scratch 3.0 values and variables.
This module defines the Value enum to represent variable values and the Variable struct to represent variables in a Scratch 3.0 project. It also includes the List struct for handling lists.
Value
Variable
List